@@ -100,13 +100,25 @@ class ConfigOptions(metaclass=ConfigMeta):
     HISTORICAL_FEATURE_OUTPUT_LOCATION: Optional[str] = None
 
     #: Default Redis host
-    REDIS_HOST: str = "localhost"
+    REDIS_HOST: Optional[str] = ""
 
     #: Default Redis port
-    REDIS_PORT: str = "6379"
+    REDIS_PORT: Optional[str] = ""
 
     #: Enable or disable TLS/SSL to Redis
-    REDIS_SSL: str = "False"
+    REDIS_SSL: Optional[str] = "False"
+
+    #: BigTable Project ID
+    BIGTABLE_PROJECT: Optional[str] = ""
+
+    #: BigTable Instance ID
+    BIGTABLE_INSTANCE: Optional[str] = ""
+
+    #: Cassandra host. Can be a comma separated string
+    CASSANDRA_HOST: Optional[str] = ""
+
+    #: Cassandra port
+    CASSANDRA_PORT: Optional[str] = ""
 
     #: Enable or disable StatsD
     STATSD_ENABLED: str = "False"
