@@ -328,9 +328,13 @@ class IngestionJobParameters(SparkJobParameters):
         feature_table: Dict,
         source: Dict,
         jar: str,
-        redis_host: str,
-        redis_port: int,
-        redis_ssl: bool,
+        redis_host: Optional[str] = None,
+        redis_port: Optional[int] = None,
+        redis_ssl: Optional[bool] = None,
+        bigtable_project: Optional[str] = None,
+        bigtable_instance: Optional[str] = None,
+        cassandra_host: Optional[str] = None,
+        cassandra_port: Optional[int] = None,
         statsd_host: Optional[str] = None,
         statsd_port: Optional[int] = None,
         deadletter_path: Optional[str] = None,
@@ -343,6 +347,10 @@ class IngestionJobParameters(SparkJobParameters):
         self._redis_host = redis_host
         self._redis_port = redis_port
         self._redis_ssl = redis_ssl
+        self._bigtable_project = bigtable_project
+        self._bigtable_instance = bigtable_instance
+        self._cassandra_host = cassandra_host
+        self._cassandra_port = cassandra_port
         self._statsd_host = statsd_host
         self._statsd_port = statsd_port
         self._deadletter_path = deadletter_path
@@ -352,6 +360,14 @@ class IngestionJobParameters(SparkJobParameters):
     def _get_redis_config(self):
         return dict(host=self._redis_host, port=self._redis_port, ssl=self._redis_ssl)
 
+    def _get_bigtable_config(self):
+        return dict(
+            project_id=self._bigtable_project, instance_id=self._bigtable_instance
+        )
+
+    def _get_cassandra_config(self):
+        return dict(host=self._cassandra_host, port=self._cassandra_port)
+
     def _get_statsd_config(self):
         return (
             dict(host=self._statsd_host, port=self._statsd_port)
@@ -377,10 +393,17 @@ class IngestionJobParameters(SparkJobParameters):
             json.dumps(self._feature_table),
             "--source",
             json.dumps(self._source),
-            "--redis",
-            json.dumps(self._get_redis_config()),
         ]
 
+        if self._redis_host and self._redis_port:
+            args.extend(["--redis", json.dumps(self._get_redis_config())])
+
+        if self._bigtable_project and self._bigtable_instance:
+            args.extend(["--bigtable", json.dumps(self._get_bigtable_config())])
+
+        if self._cassandra_host and self._cassandra_port:
+            args.extend(["--cassandra", json.dumps(self._get_cassandra_config())])
+
         if self._get_statsd_config():
             args.extend(["--statsd", json.dumps(self._get_statsd_config())])
 
@@ -409,9 +432,13 @@ class BatchIngestionJobParameters(IngestionJobParameters):
         start: datetime,
         end: datetime,
         jar: str,
-        redis_host: str,
-        redis_port: int,
-        redis_ssl: bool,
+        redis_host: Optional[str],
+        redis_port: Optional[int],
+        redis_ssl: Optional[bool],
+        bigtable_project: Optional[str],
+        bigtable_instance: Optional[str],
+        cassandra_host: Optional[str] = None,
+        cassandra_port: Optional[int] = None,
         statsd_host: Optional[str] = None,
         statsd_port: Optional[int] = None,
         deadletter_path: Optional[str] = None,
@@ -424,6 +451,10 @@ class BatchIngestionJobParameters(IngestionJobParameters):
             redis_host,
             redis_port,
             redis_ssl,
+            bigtable_project,
+            bigtable_instance,
+            cassandra_host,
+            cassandra_port,
             statsd_host,
             statsd_port,
             deadletter_path,
@@ -459,9 +490,13 @@ class StreamIngestionJobParameters(IngestionJobParameters):
         source: Dict,
         jar: str,
         extra_jars: List[str],
-        redis_host: str,
-        redis_port: int,
-        redis_ssl: bool,
+        redis_host: Optional[str],
+        redis_port: Optional[int],
+        redis_ssl: Optional[bool],
+        bigtable_project: Optional[str],
+        bigtable_instance: Optional[str],
+        cassandra_host: Optional[str] = None,
+        cassandra_port: Optional[int] = None,
         statsd_host: Optional[str] = None,
         statsd_port: Optional[int] = None,
         deadletter_path: Optional[str] = None,
@@ -476,6 +511,10 @@ class StreamIngestionJobParameters(IngestionJobParameters):
             redis_host,
             redis_port,
             redis_ssl,
+            bigtable_project,
+            bigtable_instance,
+            cassandra_host,
+            cassandra_port,
             statsd_host,
             statsd_port,
             deadletter_path,
